==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/fr-FR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessoire enregistré',
    'Accessory_Checkout_Notification' => 'Accessoire verrouillé',
    'Asset_Checkin_Notification' => 'Actif restitué',
    'Asset_Checkout_Notification' => 'Actif affecté',
    'Confirm_Accessory_Checkin' => 'Confirmation de l\'association de l\'accessoire',
    'Confirm_Asset_Checkin' => 'Confirmation de l\'association du matériel',
    'Confirm_accessory_delivery' => 'Confirmation de la livraison de l\'accessoire',
    'Confirm_asset_delivery' => 'Confirmation de la livraison du matériel',
    'Confirm_consumable_delivery' => 'Confirmation de la livraison du consommable',
    'Confirm_license_delivery' => 'Confirmation de la livraison de licence',
    'Consumable_checkout_notification' => 'Consommable checkout',
    'Days' => 'Jours',
    'Expected_Checkin_Date' => 'Un matériel que vous avez emprunté doit être vérifié à nouveau le :date',
    'Expected_Checkin_Notification' => 'Rappel : la date limite de vérification de :name approche',
    'Expected_Checkin_Report' => 'Rapport de vérification de matériel attendu',
    'Expiring_Assets_Report' => 'Rapport d\'expiration des actifs.',
    'Expiring_Licenses_Report' => 'Rapport d\'expiration des licences.',
    'Item_Request_Canceled' => 'Demande d\'article annulée',
    'Item_Requested' => 'Article demandé',
    'License_Checkin_Notification' => 'Licence enregistrée',
    'License_Checkout_Notification' => 'Licence verrouillée',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Rapport d’inventaire bas',
    'a_user_canceled' => 'Un·e utilisateur·trice a annulé une demande d’article sur le site Web',
    'a_user_requested' => 'Un·e utilisateur·trice a demandé un article sur le site Web',
    'acceptance_asset_accepted' => 'Un utilisateur a accepté un article',
    'acceptance_asset_declined' => 'Un utilisateur a refusé un article',
    'accessory_name' => 'Nom de l\'accessoire',
    'additional_notes' => 'Notes complémentaires ',
    'admin_has_created' => 'Un administrateur a créé un compte pour vous sur le site :web.',
    'asset' => 'Biens',
    'asset_name' => 'Nom de l\'actif',
    'asset_requested' => 'Produit demandé',
    'asset_tag' => 'Numéro d\'inventaire',
    'assets_warrantee_alert' => 'Il y a :count actif(s) avec une garantie expirant dans les prochains :threshold jours.|Il y a :count actif(s) avec des garanties expirant dans les prochains :threshold jours.',
    'assigned_to' => 'Affecté à',
    'best_regards' => 'Cordialement,',
    'canceled' => 'Annulé',
    'checkin_date' => 'Date de dissociation',
    'checkout_date' => 'Date d\'association',
    'checkedout_from' => 'Verrouillé depuis',
    'checkedin_from'  => 'Enregistré depuis',
    'checked_into' => 'Vérifié dans',
    'click_on_the_link_accessory' => 'Merci de cliquer sur le lien ci-dessous pour confirmer la bonne réception de l\'accessoire.',
    'click_on_the_link_asset' => 'Cliquez sur le lien ci-dessous pour confirmer que vous avez reçu l\'actif.',
    'click_to_confirm' => 'Veuillez cliquer sur le lien suivant pour confirmer votre :web account:',
    'current_QTY' => 'Quantité actuelle',
    'days' => 'jours',
    'expecting_checkin_date' => 'Date de dissociation prévue',
    'expires' => 'Expire le',
    'hello' => 'Bonjour',
    'hi' => 'Salut',
    'i_have_read' => 'J\'ai bien lu et approuvé les conditions d\'utilisation, et reçu cet objet.',
    'inventory_report' => 'Rapport d\'inventaire',
    'item' => 'Item',
    'item_checked_reminder' => 'Ceci est un rappel que vous avez actuellement :count articles que vous n\'avez pas acceptés ou refusés. Veuillez cliquer sur le lien ci-dessous pour confirmer votre décision.',
    'license_expiring_alert' => 'Il y a :count licence expirant dans les prochains :threshold jours.|Il y a :count licences expirant dans les prochains :threshold jours.',
    'link_to_update_password' => 'Veuillez cliquer sur le lien suivant pour confirmer votre :web account:',
    'login' => 'Connexion',
    'login_first_admin' => 'Connectez-vous à votre nouvelle installation Snipe-IT en utilisant les informations d\'identification ci-dessous :',
    'low_inventory_alert' => 'Il y a :count item qui est en dessous du minimum d\'inventaire ou qui sera bas sous peu.|Il y a :count articles qui sont en dessous du minimum d\'inventaire ou qui seront bas sous peu.',
    'min_QTY' => 'Quantité minimum',
    'name' => 'Nom',
    'new_item_checked' => 'Un nouvel élément a été vérifié sous votre nom, les détails sont ci-dessous.',
    'notes' => 'Notes',
    'password' => 'Mot de passe',
    'password_reset' => 'Réinitialisation du mot de passe',
    'read_the_terms' => 'Merci de lire les conditions d\'utilisation ci-dessous.',
    'read_the_terms_and_click' => 'Veuillez lire les conditions d\'utilisation ci-dessous, et cliquez sur le lien en bas pour confirmer que vous avez lu et accepté les conditions d\'utilisation, et que vous avez reçu l\'actif.',
    'requested' => 'Demandé',
    'reset_link' => 'Votre lien pour réinitialiser le mot de passe',
    'reset_password' => 'Cliquez ici pour réinitialiser votre mot de passe:',
    'rights_reserved' => 'Tous droits réservés.',
    'serial' => 'N° de série ',
    'snipe_webhook_test' => 'Test d\'intégration Snipe-IT',
    'snipe_webhook_summary' => 'Résumé du test d\'intégration Snipe-IT',
    'supplier' => 'Fournisseur',
    'tag' => 'Étiquette',
    'test_email' => 'Email test de Snipe-IT',
    'test_mail_text' => 'Il s\'agit d\'un test du système de gestion d\'actifs Snipe-IT. Si vous avez obtenu cela, le courrier fonctionne :)',
    'the_following_item' => 'L\'élément suivant a été enregistré : ',
    'to_reset' => 'Pour réinitialiser votre mot de passe :web, complétez ce formulaire:',
    'type' => 'Type ',
    'upcoming-audits' => 'Il y a :count matériel à venir pour un audit dans les :threshold jours.|Il y a :count matériels à venir pour un audit dans les :threshold jours.',
    'user' => 'Utilisateur',
    'username' => 'Nom d\'utilisateur',
    'unaccepted_asset_reminder' => 'Vous avez des actifs non acceptés.',
    'welcome' => 'Bienvenue, :name',
    'welcome_to' => 'Bienvenue sur :web!',
    'your_assets' => 'Voir vos matériels',
    'your_credentials' => 'Vos identifiants Snipe-IT',
    'mail_sent' => 'Email envoyé avec succès !',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/fr-FR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accessoire enregistré',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'Confirmation de l\'association de l\'accessoire',
    'Confirm_Asset_Checkin' => 'Confirmation de l\'association du matériel',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'Confirmation de la livraison de l\'accessoire',
    'Confirm_asset_delivery' => 'Confirmation de la livraison du matériel',
    'Confirm_consumable_delivery' => 'Confirmation de la livraison du consommable',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'Confirmation de la livraison de licence',
    'Consumable_checkout_notification' => 'Consommable checkout',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'Jours',
    'Expected_Checkin_Date' => 'Un matériel que vous avez emprunté doit être vérifié à nouveau le :date',
    'Expected_Checkin_Notification' => 'Rappel : la date limite de vérification de :name approche',
    'Expected_Checkin_Report' => 'Rapport de vérification de matériel attendu',
    'Expiring_Assets_Report' => 'Rapport d\'expiration des actifs',
    'Expiring_Licenses_Report' => 'Rapport d\'expiration des licences',
    'Item_Request_Canceled' => 'Demande d\'article annulée',
    'Item_Requested' => 'Article demandé',
    'License_Checkin_Notification' => 'Licence enregistrée',
    'License_Checkout_Notification' => 'Licence verrouillée',
    'license_for'   => 'Licence pour',
    'Low_Inventory_Report' => 'Rapport d’inventaire bas',
    'a_user_canceled' => 'Un·e utilisateur·trice a annulé une demande d’article sur le site Web',
    'a_user_requested' => 'Un·e utilisateur·trice a demandé un article sur le site Web',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'Un utilisateur a accepté un article',
    'acceptance_asset_declined' => 'Un utilisateur a refusé un article',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'Nom de l\'accessoire',
    'additional_notes' => 'Notes complémentaires ',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'Biens',
    'asset_name' => 'Nom de l\'actif',
    'asset_requested' => 'Produit demandé',
    'asset_tag' => 'Numéro d\'inventaire',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'Affecté à',
    'eol' => 'Fin de vie',
    'best_regards' => 'Cordialement,',
    'canceled' => 'Annulé',
    'checkin_date' => 'Date de dissociation',
    'checkout_date' => 'Date d\'association',
    'checkedout_from' => 'Verrouillé depuis',
    'checkedin_from'  => 'Enregistré depuis',
    'checked_into' => 'Vérifié dans',
    'click_on_the_link_accessory' => 'Merci de cliquer sur le lien ci-dessous pour confirmer la bonne réception de l\'accessoire.',
    'click_on_the_link_asset' => 'Cliquez sur le lien ci-dessous pour confirmer que vous avez reçu l\'actif.',
    'click_to_confirm' => 'Veuillez cliquer sur le lien suivant pour confirmer votre :web account:',
    'current_QTY' => 'Quantité actuelle',
    'days' => 'jours',
    'expecting_checkin_date' => 'Date de dissociation prévue',
    'expires' => 'Expire le',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'Bonjour',
    'hi' => 'Salut',
    'i_have_read' => 'J\'ai bien lu et approuvé les conditions d\'utilisation, et reçu cet objet.',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Rapport d\'inventaire',
    'item' => 'Item',
    'item_checked_reminder' => 'Ceci est un rappel que vous avez actuellement :count articles que vous n\'avez pas acceptés ou refusés. Veuillez cliquer sur le lien ci-dessous pour confirmer votre décision.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'Veuillez cliquer sur le lien suivant pour confirmer votre :web account:',
    'login' => 'Connexion',
    'login_first_admin' => 'Connectez-vous à votre nouvelle installation Snipe-IT en utilisant les informations d\'identification ci-dessous :',
    'low_inventory_alert' => 'Il y a :count item qui est en dessous du minimum d\'inventaire ou qui sera bas sous peu.|Il y a :count articles qui sont en dessous du minimum d\'inventaire ou qui seront bas sous peu.',
    'min_QTY' => 'Quantité minimum',
    'name' => 'Nom',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'Un matériel a récemment été emprunté sous votre nom et doit être accepté. Vous trouverez ci-dessous les détails correspondants.',
    'notes' => 'Notes',
    'password' => 'Mot de passe',
    'password_reset' => 'Réinitialisation du mot de passe',
    'read_the_terms' => 'Merci de lire les conditions d\'utilisation ci-dessous.',
    'read_the_terms_and_click' => 'Veuillez lire les conditions d\'utilisation ci-dessous, et cliquez sur le lien en bas pour confirmer que vous avez lu et accepté les conditions d\'utilisation, et que vous avez reçu l\'actif.',
    'requested' => 'Demandé',
    'reset_link' => 'Votre lien pour réinitialiser le mot de passe',
    'reset_password' => 'Cliquez ici pour réinitialiser votre mot de passe:',
    'rights_reserved' => 'Tous droits réservés.',
    'serial' => 'N° de série ',
    'snipe_webhook_test' => 'Test d\'intégration Snipe-IT',
    'snipe_webhook_summary' => 'Résumé du test d\'intégration Snipe-IT',
    'supplier' => 'Fournisseur',
    'tag' => 'Étiquette',
    'test_email' => 'Email test de Snipe-IT',
    'test_mail_text' => 'Il s\'agit d\'un test du système de gestion d\'actifs Snipe-IT. Si vous avez obtenu cela, le courrier fonctionne :)',
    'the_following_item' => 'L\'élément suivant a été enregistré : ',
    'to_reset' => 'Pour réinitialiser votre mot de passe :web, complétez ce formulaire:',
    'type' => 'Type ',
    'upcoming-audits' => 'Il y a :count matériel à venir pour un audit dans les :threshold jours.|Il y a :count matériels à venir pour un audit dans les :threshold jours.',
    'user' => 'Utilisateur',
    'username' => 'Nom d\'utilisateur',
    'unaccepted_asset_reminder' => 'Rappel : vous avez des actifs non acceptés.',
    'welcome' => 'Bienvenue, :name',
    'welcome_to' => 'Bienvenue sur :web!',
    'your_assets' => 'Voir vos matériels',
    'your_credentials' => 'Vos identifiants Snipe-IT',
    'mail_sent' => 'Email envoyé avec succès !',
];
